@@ -27,9 +27,9 @@ class Crawler:
     def _crawling_(self, response):
         scraper = Scraper(response)
         list_href = scraper.gethref()
-        Terminal.found(list_href.__str__())
         if list_href.count == 0: return None
         urls = list_href.map(lambda x: x.url())
+        urls.ForEach(lambda x: Terminal.found(x))
         responses = self.fetcher.get_all_pages(urls)
         responses.removeErrors()
         return responses
